diff --git a/projects/hip/docs/RuntimeAPI/html/Synchonization.html b/projects/hip/docs/RuntimeAPI/html/Synchonization.html index d1d49391dd..198f1d8d55 100644 --- a/projects/hip/docs/RuntimeAPI/html/Synchonization.html +++ b/projects/hip/docs/RuntimeAPI/html/Synchonization.html @@ -79,7 +79,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');

The following commands are "host-asynchronous" - meaning they do not wait for any preceding commands to complete, and may return control to the host thread before the requested operation completes:

@@ -109,7 +109,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); diff --git a/projects/hip/docs/RuntimeAPI/html/annotated.html b/projects/hip/docs/RuntimeAPI/html/annotated.html index 1d7e7e2a5b..7aad966bcb 100644 --- a/projects/hip/docs/RuntimeAPI/html/annotated.html +++ b/projects/hip/docs/RuntimeAPI/html/annotated.html @@ -96,20 +96,23 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); oChipDeviceProp_t oChipEvent_t oChipPointerAttribute_t -oCihipDevice_t -oCihipEvent_t -oCihipException -oCihipSignal_t -oCihipStream_t -oCStagingBuffer -oCtexture -\CtextureReference +oCihipDevice_t +oCihipDeviceCriticalBase_t +oCihipEvent_t +oCihipException +oCihipSignal_t +oCihipStream_t +oCihipStreamCriticalBase_t +oCLockedAccessor +oCLockedBase +oCStagingBuffer +\CtextureReference diff --git a/projects/hip/docs/RuntimeAPI/html/bug.html b/projects/hip/docs/RuntimeAPI/html/bug.html index ef94caaa9f..b017f3a1b0 100644 --- a/projects/hip/docs/RuntimeAPI/html/bug.html +++ b/projects/hip/docs/RuntimeAPI/html/bug.html @@ -80,22 +80,20 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-
Member hipGetDeviceProperties (hipDeviceProp_t *prop, int device)
+
Member hipGetDeviceProperties (hipDeviceProp_t *prop, int device)

HCC always returns 0 for maxThreadsPerMultiProcessor

HCC always returns 0 for regsPerBlock

HCC always returns 0 for l2CacheSize

-
Member hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream=0)
+
Member hipMemcpyPeerAsync (void *dst, int dstDevice, const void *src, int srcDevice, size_t sizeBytes, hipStream_t stream)
This function uses a synchronous copy
-
Member hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags)
-
This function conservatively waits for all work in the specified stream to complete.
-
Member ihipDevice_t::getProperties (hipDeviceProp_t *prop)
-
: on HCC, isMultiGpuBoard returns True if system contains multiple GPUS (rather than if GPU is on a multi-ASIC board)
+
Member hipStreamWaitEvent (hipStream_t stream, hipEvent_t event, unsigned int flags)
+
This function conservatively waits for all work in the specified stream to complete.
diff --git a/projects/hip/docs/RuntimeAPI/html/structtexture-members.html b/projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html similarity index 79% rename from projects/hip/docs/RuntimeAPI/html/structtexture-members.html rename to projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html index 04556bf525..bd3173d921 100644 --- a/projects/hip/docs/RuntimeAPI/html/structtexture-members.html +++ b/projects/hip/docs/RuntimeAPI/html/classFakeMutex-members.html @@ -84,20 +84,19 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-
texture< T, texType, hipTextureReadMode > Member List
+
FakeMutex Member List
-

This is the complete list of members for texture< T, texType, hipTextureReadMode >, including all inherited members.

+

This is the complete list of members for FakeMutex, including all inherited members.

- - - - + + +
_dataPtr (defined in texture< T, texType, hipTextureReadMode >)texture< T, texType, hipTextureReadMode >
channelDesc (defined in textureReference)textureReference
filterMode (defined in textureReference)textureReference
normalized (defined in textureReference)textureReference
lock() (defined in FakeMutex)FakeMutexinline
try_lock() (defined in FakeMutex)FakeMutexinline
unlock() (defined in FakeMutex)FakeMutexinline
diff --git a/projects/hip/docs/RuntimeAPI/html/structchar3.html b/projects/hip/docs/RuntimeAPI/html/classFakeMutex.html similarity index 70% rename from projects/hip/docs/RuntimeAPI/html/structchar3.html rename to projects/hip/docs/RuntimeAPI/html/classFakeMutex.html index bc38841645..99265880e5 100644 --- a/projects/hip/docs/RuntimeAPI/html/structchar3.html +++ b/projects/hip/docs/RuntimeAPI/html/classFakeMutex.html @@ -4,7 +4,7 @@ -HIP: Heterogenous-computing Interface for Portability: char3 Struct Reference +HIP: Heterogenous-computing Interface for Portability: FakeMutex Class Reference @@ -72,7 +72,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); onmouseover="return searchBox.OnSearchSelectShow()" onmouseout="return searchBox.OnSearchSelectHide()" onkeydown="return searchBox.OnSearchSelectKey(event)"> - All Classes Files Functions Variables Enumerations Enumerator Macros Groups Pages + All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
@@ -84,32 +84,32 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-Public Attributes | -List of all members
+Public Member Functions | +List of all members
-
char3 Struct Reference
+
FakeMutex Class Reference
- - - - - - - + + + + + + +

-Public Attributes

-char x
 
-char y
 
-char z
 

+Public Member Functions

+void lock ()
 
+bool try_lock ()
 
+void unlock ()
 
-
The documentation for this struct was generated from the following file:
diff --git a/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html new file mode 100644 index 0000000000..0440c28c7e --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor-members.html @@ -0,0 +1,105 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: Member List + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+
LockedAccessor< T > Member List
+
+
+ +

This is the complete list of members for LockedAccessor< T >, including all inherited members.

+ + + + + +
LockedAccessor(T &criticalData, bool autoUnlock=true) (defined in LockedAccessor< T >)LockedAccessor< T >inline
operator->() (defined in LockedAccessor< T >)LockedAccessor< T >inline
unlock() (defined in LockedAccessor< T >)LockedAccessor< T >inline
~LockedAccessor() (defined in LockedAccessor< T >)LockedAccessor< T >inline
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html new file mode 100644 index 0000000000..1712e382f9 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classLockedAccessor.html @@ -0,0 +1,117 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: LockedAccessor< T > Class Template Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+Public Member Functions | +List of all members
+
+
LockedAccessor< T > Class Template Reference
+
+
+ + + + + + + + +

+Public Member Functions

LockedAccessor (T &criticalData, bool autoUnlock=true)
 
+void unlock ()
 
+T * operator-> ()
 
+
The documentation for this class was generated from the following file: +
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classes.html b/projects/hip/docs/RuntimeAPI/html/classes.html index 205d994eda..a36250a427 100644 --- a/projects/hip/docs/RuntimeAPI/html/classes.html +++ b/projects/hip/docs/RuntimeAPI/html/classes.html @@ -87,28 +87,31 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
Class Index
-
D | F | H | I | S | T
+
D | F | H | I | L | S | T
+ + + - - - + + + - - + +
  F  
+
  S  
+
hipDeviceArch_t   ihipDeviceCriticalBase_t   
hipDeviceProp_t   ihipEvent_t   
FakeMutex   StagingBuffer   hipEvent_t   ihipException   
  L  
  d  
-
hipDeviceArch_t   ihipEvent_t   textureReference   
hipDeviceProp_t   ihipException   
FakeMutex   dim3   hipEvent_t   ihipSignal_t   
  S  
-
  h  
-
hipPointerAttribute_t   ihipStream_t   
hipPointerAttribute_t   ihipSignal_t   
  i  
-
  t  
+
ihipStream_t   
LockedAccessor   dim3   ihipStreamCriticalBase_t   
LockedBase   
  h  
+
ihipDevice_t   
  t  
StagingBuffer   hipChannelFormatDesc   
ihipDevice_t   texture   
hipChannelFormatDesc   textureReference   
-
D | F | H | I | S | T
+
D | F | H | I | L | S | T
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html new file mode 100644 index 0000000000..02331c2b9e --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t-members.html @@ -0,0 +1,116 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: Member List + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+
ihipDeviceCriticalBase_t< MUTEX_TYPE > Member List
+
+
+ +

This is the complete list of members for ihipDeviceCriticalBase_t< MUTEX_TYPE >, including all inherited members.

+ + + + + + + + + + + + + + + + +
_mutex (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >private
addPeer(ihipDevice_t *peer) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >
const_streams() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
ihipDeviceCriticalBase_t() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
incStreamId() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
init(unsigned deviceCnt) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
lock() (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >inlineprivate
LockedAccessor< ihipDeviceCriticalBase_t > (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >friend
peerAgents() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
peerCnt() const (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
removePeer(ihipDevice_t *peer) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >
resetPeers(ihipDevice_t *thisDevice) (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >
streams() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
unlock() (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >inlineprivate
~ihipDeviceCriticalBase_t() (defined in ihipDeviceCriticalBase_t< MUTEX_TYPE >)ihipDeviceCriticalBase_t< MUTEX_TYPE >inline
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html new file mode 100644 index 0000000000..91ecb9dfe3 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.html @@ -0,0 +1,151 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: ihipDeviceCriticalBase_t< MUTEX_TYPE > Class Template Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+Public Member Functions | +Friends | +List of all members
+
+
ihipDeviceCriticalBase_t< MUTEX_TYPE > Class Template Reference
+
+
+
+Inheritance diagram for ihipDeviceCriticalBase_t< MUTEX_TYPE >:
+
+
+ + +LockedBase< MUTEX_TYPE > + +
+ + + + + + + + + + + + + + + + + + + + +

+Public Member Functions

+void init (unsigned deviceCnt)
 
+std::list< ihipStream_t * > & streams ()
 
+const std::list< ihipStream_t * > & const_streams () const
 
+ihipStream_t::SeqNum_t incStreamId ()
 
+bool addPeer (ihipDevice_t *peer)
 
+bool removePeer (ihipDevice_t *peer)
 
+void resetPeers (ihipDevice_t *thisDevice)
 
+uint32_t peerCnt () const
 
+hsa_agent_t * peerAgents () const
 
+ + + +

+Friends

+class LockedAccessor< ihipDeviceCriticalBase_t >
 
+
The documentation for this class was generated from the following file: +
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png new file mode 100644 index 0000000000..5b18856aed Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipDeviceCriticalBase__t.png differ diff --git a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html similarity index 55% rename from projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html rename to projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html index 18910d1c14..bc1a11bd75 100644 --- a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t-members.html +++ b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t-members.html @@ -88,33 +88,29 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-

This is the complete list of members for ihipDevice_t, including all inherited members.

+

This is the complete list of members for ihipDevice_t, including all inherited members.

- - - - - - - - - - - - - - - - - - - - - + + + + + + + + + + + + + + + + +
_acc (defined in ihipDevice_t)ihipDevice_t
_compute_units (defined in ihipDevice_t)ihipDevice_t
_copy_lock (defined in ihipDevice_t)ihipDevice_t
_default_stream (defined in ihipDevice_t)ihipDevice_t
_device_index (defined in ihipDevice_t)ihipDevice_t
_hsa_agent (defined in ihipDevice_t)ihipDevice_t
_null_stream (defined in ihipDevice_t)ihipDevice_t
_props (defined in ihipDevice_t)ihipDevice_t
_staging_buffer (defined in ihipDevice_t)ihipDevice_t
_stream_id (defined in ihipDevice_t)ihipDevice_t
_streams (defined in ihipDevice_t)ihipDevice_t
getProperties(hipDeviceProp_t *prop)ihipDevice_t
getProperties(hipDeviceProp_t *prop) (defined in ihipDevice_t)ihipDevice_t
init(unsigned device_index, hc::accelerator acc) (defined in ihipDevice_t)ihipDevice_t
init(unsigned device_index, hc::accelerator acc) (defined in ihipDevice_t)ihipDevice_t
reset() (defined in ihipDevice_t)ihipDevice_t
reset() (defined in ihipDevice_t)ihipDevice_t
syncDefaultStream(bool waitOnSelf) (defined in ihipDevice_t)ihipDevice_tinline
waitAllStreams() (defined in ihipDevice_t)ihipDevice_tinline
~ihipDevice_t() (defined in ihipDevice_t)ihipDevice_t
~ihipDevice_t() (defined in ihipDevice_t)ihipDevice_t
_acc (defined in ihipDevice_t)ihipDevice_t
_compute_units (defined in ihipDevice_t)ihipDevice_t
_default_stream (defined in ihipDevice_t)ihipDevice_t
_device_flags (defined in ihipDevice_t)ihipDevice_t
_device_index (defined in ihipDevice_t)ihipDevice_t
_hsa_agent (defined in ihipDevice_t)ihipDevice_t
_props (defined in ihipDevice_t)ihipDevice_t
_staging_buffer (defined in ihipDevice_t)ihipDevice_t
criticalData() (defined in ihipDevice_t)ihipDevice_tinline
ihipDevice_t() (defined in ihipDevice_t)ihipDevice_tinline
init(unsigned device_index, unsigned deviceCnt, hc::accelerator &acc, unsigned flags) (defined in ihipDevice_t)ihipDevice_t
locked_addStream(ihipStream_t *s) (defined in ihipDevice_t)ihipDevice_t
locked_removeStream(ihipStream_t *s) (defined in ihipDevice_t)ihipDevice_t
locked_reset() (defined in ihipDevice_t)ihipDevice_t
locked_syncDefaultStream(bool waitOnSelf) (defined in ihipDevice_t)ihipDevice_t
locked_waitAllStreams() (defined in ihipDevice_t)ihipDevice_t
~ihipDevice_t() (defined in ihipDevice_t)ihipDevice_t
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html similarity index 62% rename from projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html rename to projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html index 9b98762848..9f3ed0481d 100644 --- a/projects/hip/docs/RuntimeAPI/html/structihipDevice__t.html +++ b/projects/hip/docs/RuntimeAPI/html/classihipDevice__t.html @@ -4,7 +4,7 @@ -HIP: Heterogenous-computing Interface for Portability: ihipDevice_t Struct Reference +HIP: Heterogenous-computing Interface for Portability: ihipDevice_t Class Reference @@ -86,37 +86,35 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
Public Member Functions | Public Attributes | -List of all members
+List of all members
-
ihipDevice_t Struct Reference
+
ihipDevice_t Class Reference
- - - - - - - - - - - - - - - - + + + + + + + + + + + + + +

Public Member Functions

-void init (unsigned device_index, hc::accelerator acc)
 
-void reset ()
 
hipError_t getProperties (hipDeviceProp_t *prop)
 
-void waitAllStreams ()
 
-void syncDefaultStream (bool waitOnSelf)
 
-void reset ()
 
-void init (unsigned device_index, hc::accelerator acc)
 
-hipError_t getProperties (hipDeviceProp_t *prop)
 
+void init (unsigned device_index, unsigned deviceCnt, hc::accelerator &acc, unsigned flags)
 
+void locked_addStream (ihipStream_t *s)
 
+void locked_removeStream (ihipStream_t *s)
 
+void locked_reset ()
 
+void locked_waitAllStreams ()
 
+void locked_syncDefaultStream (bool waitOnSelf)
 
+ihipDeviceCritical_tcriticalData ()
 
@@ -135,51 +133,24 @@ hsa_agent_t  - - - - - - - - - - + + +

Public Attributes

_hsa_agent
ihipStream_t_default_stream
 
-std::list< ihipStream_t * > _streams
 
unsigned _compute_units
 
+
StagingBuffer_staging_buffer [2]
 
-ihipStream_t::SeqNum_t _stream_id
 
-ihipStream_t_null_stream
 
-std::mutex _copy_lock [2]
 
 
+unsigned _device_flags
 
-

Member Function Documentation

- -
-
- - - - - - - - -
hipError_t ihipDevice_t::getProperties (hipDeviceProp_tprop)
-
-
Bug:
: on HCC, isMultiGpuBoard returns True if system contains multiple GPUS (rather than if GPU is on a multi-ASIC board)
- -
-
-
The documentation for this struct was generated from the following files:
diff --git a/projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipException-members.html similarity index 77% rename from projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html rename to projects/hip/docs/RuntimeAPI/html/classihipException-members.html index 57df3ae1ba..937af05387 100644 --- a/projects/hip/docs/RuntimeAPI/html/structihipStream__t-members.html +++ b/projects/hip/docs/RuntimeAPI/html/classihipException-members.html @@ -84,21 +84,18 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
-
ihipStream_t Member List
+
ihipException Member List
-

This is the complete list of members for ihipStream_t, including all inherited members.

+

This is the complete list of members for ihipException, including all inherited members.

- - - - - + +
_av (defined in ihipStream_t)ihipStream_t
_device_index (defined in ihipStream_t)ihipStream_t
_flags (defined in ihipStream_t)ihipStream_t
_last_command (defined in ihipStream_t)ihipStream_t
ihipStream_t(unsigned device_index, hc::accelerator_view av, unsigned int flags) (defined in ihipStream_t)ihipStream_tinline
_code (defined in ihipException)ihipException
ihipException(hipError_t e) (defined in ihipException)ihipExceptioninline
diff --git a/projects/hip/docs/RuntimeAPI/html/classihipException.html b/projects/hip/docs/RuntimeAPI/html/classihipException.html new file mode 100644 index 0000000000..1e57d7e471 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipException.html @@ -0,0 +1,126 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: ihipException Class Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+Public Member Functions | +Public Attributes | +List of all members
+
+
ihipException Class Reference
+
+
+
+Inheritance diagram for ihipException:
+
+
+ + + +
+ + + + +

+Public Member Functions

ihipException (hipError_t e)
 
+ + + +

+Public Attributes

+hipError_t _code
 
+
The documentation for this class was generated from the following file: +
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipException.png b/projects/hip/docs/RuntimeAPI/html/classihipException.png new file mode 100644 index 0000000000..36add951e6 Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipException.png differ diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html new file mode 100644 index 0000000000..60f9c4996e --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t-members.html @@ -0,0 +1,114 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: Member List + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+
ihipStreamCriticalBase_t< MUTEX_TYPE > Member List
+
+
+ +

This is the complete list of members for ihipStreamCriticalBase_t< MUTEX_TYPE >, including all inherited members.

+ + + + + + + + + + + + + + +
_last_command_type (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_last_copy_signal (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_last_kernel_future (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_mutex (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >
_oldest_live_sig_id (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_signalCursor (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_signalPool (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
_stream_sig_id (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >
ihipStreamCriticalBase_t() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >inline
lock() (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >inline
mlock() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >inline
unlock() (defined in LockedBase< MUTEX_TYPE >)LockedBase< MUTEX_TYPE >inline
~ihipStreamCriticalBase_t() (defined in ihipStreamCriticalBase_t< MUTEX_TYPE >)ihipStreamCriticalBase_t< MUTEX_TYPE >inline
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html new file mode 100644 index 0000000000..96f9d656fc --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.html @@ -0,0 +1,157 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: ihipStreamCriticalBase_t< MUTEX_TYPE > Class Template Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+Public Member Functions | +Public Attributes | +List of all members
+
+
ihipStreamCriticalBase_t< MUTEX_TYPE > Class Template Reference
+
+
+
+Inheritance diagram for ihipStreamCriticalBase_t< MUTEX_TYPE >:
+
+
+ + +LockedBase< MUTEX_TYPE > + +
+ + + + + + + + + +

+Public Member Functions

+ihipStreamCriticalBase_t
+< StreamMutex > * 
mlock ()
 
- Public Member Functions inherited from LockedBase< MUTEX_TYPE >
+void lock ()
 
+void unlock ()
 
+ + + + + + + + + + + + + + + + + + +

+Public Attributes

+ihipCommand_t _last_command_type
 
+ihipSignal_t_last_copy_signal
 
+hc::completion_future _last_kernel_future
 
+int _signalCursor
 
+SIGSEQNUM _oldest_live_sig_id
 
+std::deque< ihipSignal_t_signalPool
 
+SIGSEQNUM _stream_sig_id
 
- Public Attributes inherited from LockedBase< MUTEX_TYPE >
+MUTEX_TYPE _mutex
 
+
The documentation for this class was generated from the following file: +
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png new file mode 100644 index 0000000000..4d8990f4ca Binary files /dev/null and b/projects/hip/docs/RuntimeAPI/html/classihipStreamCriticalBase__t.png differ diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html b/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html new file mode 100644 index 0000000000..3a51df77a0 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipStream__t-members.html @@ -0,0 +1,121 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: Member List + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+
ihipStream_t Member List
+
+
+ +

This is the complete list of members for ihipStream_t, including all inherited members.

+ + + + + + + + + + + + + + + + + + + + + +
_av (defined in ihipStream_t)ihipStream_t
_flags (defined in ihipStream_t)ihipStream_t
_id (defined in ihipStream_t)ihipStream_t
allocSignal(LockedAccessor_StreamCrit_t &crit) (defined in ihipStream_t)ihipStream_t
copyAsync(void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t)ihipStream_t
copySync(LockedAccessor_StreamCrit_t &crit, void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t)ihipStream_t
getDevice() const (defined in ihipStream_t)ihipStream_t
ihipStream_t(unsigned device_index, hc::accelerator_view av, unsigned int flags) (defined in ihipStream_t)ihipStream_t
lastCopySeqId(LockedAccessor_StreamCrit_t &crit) (defined in ihipStream_t)ihipStream_tinline
lockclose_postKernelCommand(hc::completion_future &kernel_future) (defined in ihipStream_t)ihipStream_t
locked_copySync(void *dst, const void *src, size_t sizeBytes, unsigned kind) (defined in ihipStream_t)ihipStream_t
locked_lastCopySeqId() (defined in ihipStream_t)ihipStream_tinline
locked_reclaimSignals(SIGSEQNUM sigNum) (defined in ihipStream_t)ihipStream_t
locked_wait(bool assertQueueEmpty=false) (defined in ihipStream_t)ihipStream_t
lockopen_preKernelCommand() (defined in ihipStream_t)ihipStream_t
operator<< (defined in ihipStream_t)ihipStream_tfriend
preCopyCommand(LockedAccessor_StreamCrit_t &crit, ihipSignal_t *lastCopy, hsa_signal_t *waitSignal, ihipCommand_t copyType) (defined in ihipStream_t)ihipStream_t
SeqNum_t typedef (defined in ihipStream_t)ihipStream_t
wait(LockedAccessor_StreamCrit_t &crit, bool assertQueueEmpty=false) (defined in ihipStream_t)ihipStream_t
~ihipStream_t() (defined in ihipStream_t)ihipStream_t
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html b/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html new file mode 100644 index 0000000000..3c101e9bc0 --- /dev/null +++ b/projects/hip/docs/RuntimeAPI/html/classihipStream__t.html @@ -0,0 +1,178 @@ + + + + + + +HIP: Heterogenous-computing Interface for Portability: ihipStream_t Class Reference + + + + + + + + + +
+
+ + + + + + +
+
HIP: Heterogenous-computing Interface for Portability +
+
+
+ + + + + + +
+ All Classes Files Functions Variables Typedefs Enumerations Enumerator Macros Groups Pages
+ + +
+ +
+ +
+
+
+Public Types | +Public Member Functions | +Public Attributes | +Friends | +List of all members
+
+
ihipStream_t Class Reference
+
+
+ + + + +

+Public Types

+typedef uint64_t SeqNum_t
 
+ + + + + + + + + + + + + + + + + + + + + + + + + + + + + +

+Public Member Functions

ihipStream_t (unsigned device_index, hc::accelerator_view av, unsigned int flags)
 
+void copySync (LockedAccessor_StreamCrit_t &crit, void *dst, const void *src, size_t sizeBytes, unsigned kind)
 
+void locked_copySync (void *dst, const void *src, size_t sizeBytes, unsigned kind)
 
+void copyAsync (void *dst, const void *src, size_t sizeBytes, unsigned kind)
 
+bool lockopen_preKernelCommand ()
 
+void lockclose_postKernelCommand (hc::completion_future &kernel_future)
 
+int preCopyCommand (LockedAccessor_StreamCrit_t &crit, ihipSignal_t *lastCopy, hsa_signal_t *waitSignal, ihipCommand_t copyType)
 
+void locked_reclaimSignals (SIGSEQNUM sigNum)
 
+void locked_wait (bool assertQueueEmpty=false)
 
+SIGSEQNUM locked_lastCopySeqId ()
 
+void wait (LockedAccessor_StreamCrit_t &crit, bool assertQueueEmpty=false)
 
+SIGSEQNUM lastCopySeqId (LockedAccessor_StreamCrit_t &crit)
 
+ihipSignal_tallocSignal (LockedAccessor_StreamCrit_t &crit)
 
+ihipDevice_tgetDevice () const
 
+ + + + + + + +

+Public Attributes

+SeqNum_t _id
 
+hc::accelerator_view _av
 
+unsigned _flags
 
+ + + +

+Friends

+std::ostream & operator<< (std::ostream &os, const ihipStream_t &s)
 
+
The documentation for this class was generated from the following files: +
+ + + + diff --git a/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html b/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html index 71b55290ce..8ea47d84d0 100644 --- a/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html +++ b/projects/hip/docs/RuntimeAPI/html/dir_68267d1309a1af8e8297ef4c3efbcdba.html @@ -4,7 +4,7 @@ -HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP-privatestaging/src Directory Reference +HIP: Heterogenous-computing Interface for Portability: /home/mangupta/hip_git/rel0.84.0/src Directory Reference @@ -86,9 +86,21 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); + + + + + + + + - + + + + + @@ -96,7 +108,7 @@ Files diff --git a/projects/hip/docs/RuntimeAPI/html/dir_6d8604cb65fa6b83549668eb0ce09cac.html b/projects/hip/docs/RuntimeAPI/html/dir_6d8604cb65fa6b83549668eb0ce09cac.html index 32a8932ad9..818899bc59 100644 --- a/projects/hip/docs/RuntimeAPI/html/dir_6d8604cb65fa6b83549668eb0ce09cac.html +++ b/projects/hip/docs/RuntimeAPI/html/dir_6d8604cb65fa6b83549668eb0ce09cac.html @@ -4,7 +4,7 @@ -HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP-privatestaging/include/hcc_detail Directory Reference +HIP: Heterogenous-computing Interface for Portability: /home/mangupta/hip_git/rel0.84.0/include/hcc_detail Directory Reference @@ -86,6 +86,10 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');

Files

file  device_util.cpp
 
file  hip_device.cpp
 
file  hip_error.cpp
 
file  hip_event.cpp
 
file  hip_hcc.cpp
 
file  hip_hcc2.cpp
file  hip_memory.cpp
 
file  hip_peer.cpp
 
file  hip_stream.cpp
 
file  staging_buffer.cpp
 
+ + + + @@ -95,6 +99,8 @@ Files + + @@ -109,7 +115,7 @@ Files diff --git a/projects/hip/docs/RuntimeAPI/html/dir_d44c64559bbebec7f509842c48db8b23.html b/projects/hip/docs/RuntimeAPI/html/dir_d44c64559bbebec7f509842c48db8b23.html index 1eaa18e079..7a9bf94f64 100644 --- a/projects/hip/docs/RuntimeAPI/html/dir_d44c64559bbebec7f509842c48db8b23.html +++ b/projects/hip/docs/RuntimeAPI/html/dir_d44c64559bbebec7f509842c48db8b23.html @@ -4,7 +4,7 @@ -HIP: Heterogenous-computing Interface for Portability: /home/bensander/HIP-privatestaging/include Directory Reference +HIP: Heterogenous-computing Interface for Portability: /home/mangupta/hip_git/rel0.84.0/include Directory Reference @@ -91,6 +91,8 @@ Directories

Files

file  hcc_acc.h [code]
 
file  hip_hcc.h [code]
 
file  hip_runtime.h [code]
 Contains definitions of APIs for HIP runtime.
 
file  hip_texture.h [code]
 HIP C++ Texture API for hcc compiler.
 
file  hip_util.h [code]
 
file  hip_vector_types.h [code]
 Defines the different newt vector types for HIP runtime.
 
+ + @@ -103,7 +105,7 @@ Files diff --git a/projects/hip/docs/RuntimeAPI/html/files.html b/projects/hip/docs/RuntimeAPI/html/files.html index 0e4f7bba8b..9c4227fd9d 100644 --- a/projects/hip/docs/RuntimeAPI/html/files.html +++ b/projects/hip/docs/RuntimeAPI/html/files.html @@ -89,17 +89,21 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search');
[detail level 123]

Files

file  hcc.h [code]
 
file  hip_common.h [code]
 
file  hip_runtime.h [code]
- - - - - - - - - - - + + + + + + + + + + + + + + +
o-include
|o-hcc_detail
||o*hip_runtime.hContains definitions of APIs for HIP runtime
||o*hip_runtime_api.hContains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h
||o*hip_texture.hHIP C++ Texture API for hcc compiler
||o*hip_vector_types.hDefines the different newt vector types for HIP runtime
||o*host_defines.hTODO-doc
||o*staging_buffer.h
||\*trace_helper.h
|o*hip_common.h
|o*hip_runtime.h
|o*hip_runtime_api.h
|\*hip_vector_types.h
||o*hcc_acc.h
||o*hip_hcc.h
||o*hip_runtime.hContains definitions of APIs for HIP runtime
||o*hip_runtime_api.hContains C function APIs for HIP runtime. This file does not use any HCC builtin or special language extensions (-hc mode) ; those functions in hip_runtime.h
||o*hip_texture.hHIP C++ Texture API for hcc compiler
||o*hip_util.h
||o*hip_vector_types.hDefines the different newt vector types for HIP runtime
||o*host_defines.hTODO-doc
||o*staging_buffer.h
||\*trace_helper.h
|o*hcc.h
|o*hip_common.h
|o*hip_runtime.h
|o*hip_runtime_api.h
|\*hip_vector_types.h
\-src
 \*hip_hcc.cpp
@@ -107,7 +111,7 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); diff --git a/projects/hip/docs/RuntimeAPI/html/functions.html b/projects/hip/docs/RuntimeAPI/html/functions.html index e6a4e60528..2eabb218cc 100644 --- a/projects/hip/docs/RuntimeAPI/html/functions.html +++ b/projects/hip/docs/RuntimeAPI/html/functions.html @@ -70,7 +70,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); @@ -78,7 +77,6 @@ var searchBox = new SearchBox("searchBox", "search",false,'Search'); -

- g -

- -

- h -